@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.02.
 package Dancer2::Plugin::LogReport;
 use vars '$VERSION';
-$VERSION = '1.14';
+$VERSION = '1.15';
 
 
 use warnings;
@@ -181,8 +181,9 @@ sub _error_handler($$$$)
         # handle it.
         # return not needed because of Return::MultiLevel hack, but let's
         # leave it in anyway in hope.
+        my $fwd_url = $_settings->{forward_url} || '';
         return _forward_home($_dsl, $_[0])
-            if $req->uri ne $_settings->{forward_url} || !$req->is_get;
+            if $req->uri ne $fwd_url || !$req->is_get;
 
         return;
     };
